==> rospell-2006.01.tar.gz: rospell-2006.01/src/rospell/main.cpp <==
//****************************************************************************
// Copyright (C) 2005,  Lucian Constantin <struct_bylighting@yahoo.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//****************************************************************************

#include <qapplication.h>
#include <qdesktopwidget.h>
#include "spell.h"
#include "global.h"
#include "qwerty.h"


static void usage() {
	printf("NAME\n");
	printf("   rospell - editor si corector/speller UTF-8 pentru limba romana.\n");
	printf("\n");
	printf("SYNOPSYS\n");
	printf("   rospell [options] filename\n");
	printf("\n");
	printf("DESCRIPTION\n");
	printf("   rospell este structurat ca un editor de text similar cu gedit. Pentru a\n");
	printf("   porni spelling-ul din pozitia curenta a cursorului, apasati meniul\n");
	printf("   Start Spelling. Folositi Ignore pentru a sari peste un cuvant,\n");
	printf("   sau Add pentru a adauga cuvantul in dictionarul user local\n");
	printf("   aflat in directorul /home/username/.rospell.\n");
	printf("\n");
	printf("   rospell suporta seturile de caractere UTF-8, ISO8859-2/16 si CP1250.\n");
	printf("   Daca formatul nu este specificat folosind --iso8859-2/16 sau --cp1250,\n");
	printf("   fisierele sunt presupuse a fi in format UTF-8.\n");
	printf("\n");
	printf("   rospell foloseste tasta ALT din partea drepta a barei de spatiu\n");
	printf("   pentru introducerea caracterelor diacritice romanesti dupa cum urmeaza:\n");
	printf("\n");
	printf("       ALT-a, ALT-s, ALT-q, ALT-t, ALT-i\n");
	printf("\n");
	printf("OPTIONS\n");
	printf("   -v: versiunea instalata.\n");
	printf("\n");
	printf("   -h, -?, --help: acest ecran de help.\n");
	printf("\n");
	printf("   --iso8859-2: fisierele sunt in format ISO8859-2.\n");
	printf("\n");
	printf("   --iso8859-16: fisierele sunt in format ISO8859-16.\n");
	printf("\n");
	printf("   --cp1250: fisierele sunt in format CP1250 (Windows).\n");
	printf("\n");
	printf("   (urmatoarele optiuni sunt valabile numai pentru formatul UTF-8)\n");
	printf("\n");
	printf("   -m: adauga toate cuvintele la dictionarul master romanesc\n");
	printf("\n");
	printf("   -e: adauga toate cuvintele la dictionarul master englezesc\n");
	printf("\n");
	printf("   -u: adauga toate cuvintele la dictionarul user\n");
	printf("\n");
	printf("   -p: tipareste cuvintele noi\n");
	printf("\n");
	printf("EXAMPLE\n");
	printf("   $ rospell file*.txt\n");
	printf("   - porneste speller-ul in format default UTF-8\n");
	printf("\n");
	printf("   $ rospell --iso8859-2 file*.txt\n");
	printf("   - porneste speller-ul in format ISO8859-2\n");
	printf("\n");
	printf("   $ rospell -p file*.txt\n");
	printf("   - genereaza o lista de cuvinte necunoscute de catre speller din\n");
	printf("   fisierele specificate\n");
	printf("\n");
	printf("AUTHOR\n");
	printf("   http://rospell.sourceforge.net\n");
}

static Editor *start(const char *fname, FILE_FORMAT format) {
	LOG("start");
	Editor *e = new Editor;
	e->setDefaultFormat(format);

	if (fname == 0) {
		LOG("start with no file");
		e->setFname(0);
	} else {
		e->setFname(fname);
		e->load(fname);
	}

	bool isSmall =  qApp->desktop()->size().width() < 450
				 || qApp->desktop()->size().height() < 450;

	if (isSmall) {
		e->showMaximized();
	} else {
		LOG("main: set editor sizes %d %d", Global::instance()->xsize, Global::instance()->ysize);
//		e->resize(Global::instance()->xsize, Global::instance()->ysize);
		e->show();
	}

	return e;
}

int main( int argc, char **argv )
{
	Action *aptr = 0;
	int start_arg = 1;
	LOG("argc %d", argc);
	LOG("argv %s %s", argv[0], argv[1]);


	FILE_FORMAT format = FILE_UTF8;

	if (argc > 1) {
		if (strcmp(argv[1], "--iso8859-2") == 0) {
			LOG("main: option -iso8859-2");
			format = FILE_ISO8859_2;
			start_arg = 2;
		}

		if (strcmp(argv[1], "--iso8859-16") == 0) {
			LOG("main: option -iso8859-16");
			format = FILE_ISO8859_16;
			start_arg = 2;
		}

		if (strcmp(argv[1], "--cp1250") == 0) {
			LOG("main: option -cp1250");
			format = FILE_CP1250;
			start_arg = 2;
		}

		if (strcmp(argv[1], "-m") == 0) { // Romanian master dict
			aptr = new ActionAddAllMaster();
			Global::instance()->addallmaster = true;
			LOG("Global::addallmaster = true");
			start_arg = 2;
			if (argc <= 2) {
				usage();
				return 1;
			}
		} else if (strcmp(argv[1], "-e") == 0) { // English master dict
			aptr = new ActionAddAllMasterEnglish();
			Global::instance()->addallmasterenglish = true;
			LOG("Global::addallmasterenglish = true");
			start_arg = 2;
			if (argc <= 2) {
				usage();
				return 1;
			}
		} else if (strcmp(argv[1], "-u") == 0) {
			aptr = new ActionAddAllUser();
			Global::instance()->addalluser = true;
			start_arg = 2;
			if (argc <= 2) {
				usage();
				return 1;
			}
		} else if (strcmp(argv[1], "-p") == 0) {
			aptr = new ActionDumpAll();
			Global::instance()->dumpall = true;
			start_arg = 2;
			if (argc <= 2) {
				usage();
				return 1;
			}
		} else if (strcmp(argv[1], "-h") == 0 ||
				 strcmp(argv[1], "-?") == 0 ||
				 strcmp(argv[1], "--help") == 0) {
			usage();
			return 0;
		} else if (strcmp(argv[1], "-v") == 0) {
			printf("rospell versiunea %s\n", VERSION);
			return 0;
		}
	}

	if (aptr != 0) {
		Dictionaries *pdict = new Dictionaries(!(Global::instance()->addallmaster || Global::instance()->addallmasterenglish));
	
		if (!Global::instance()->addallmaster && !Global::instance()->addallmasterenglish) {
			readHomeDir(pdict);
		}
	
		for (int i = start_arg; i < argc; i++) {
			char *fstr = UTILS::read_file_malloc(argv[i]);
			if (fstr == 0)
				continue;
			fprintf(stderr, "Process file %s\n", argv[i]);
			LOG("Process file %s", argv[i]);
			char *ptmp = spell(pdict, aptr, fstr);
			delete[] ptmp;
		}
		delete aptr;
	
		if (Global::instance()->addallmaster || Global::instance()->addallmasterenglish) {
			pdict->saveMaster();
		}
#ifndef _WIN32
		delete pdict;
#else
		LOG("problems with delete on windows (%s:%d)", __FILE__, __LINE__);
#endif
		Stats::instance()->print();
		Stats::instance(true);
		if (Global::instance()->addallmaster ||
		    Global::instance()->addallmasterenglish ||
		    Global::instance()->addalluser ||
		    Global::instance()->dumpall) {
			return 0;
		}
	}
	QApplication a( argc, argv);

	int i;
	Editor *e = 0;
	if (argc == start_arg)
		e = start(0, format);
	else {
		e = start(argv[start_arg], format);
		start_arg++;
		for (i= start_arg; i<argc; i++) {
			e->load(argv[i]);
		}
	}
	if (e == 0) // just in case!
		return 1;
	a.connect( &a, SIGNAL(lastWindowClosed()), &a, SLOT(quit()) );

	int retval = a.exec();
	delete e;
	Global::instance(true);
	Stats::instance(true);
	return retval;
//    return a.exec();
}

==> rospell-2007.00.tar.gz: rospell-2007.00/src/rospell/main.cpp <==
//****************************************************************************
// Copyright (C) 2005,  Lucian Constantin <struct_bylighting@yahoo.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//****************************************************************************

#include <qapplication.h>
#include <qdesktopwidget.h>
#include "spell.h"
#include "qwerty.h"


static void usage() {
	printf("NAME\n");
	printf("   rospell - UTF-8 programming text editor and speller.\n");
	printf("\n");
	printf("SYNOPSYS\n");
	printf("   rospell [options] filename\n");
	printf("\n");
	printf("DESCRIPTION\n");
	printf("   rospell is a programming text editor and speller. To start the spelling\n");
	printf("   from the current cursor position press Start Spelling. Use Ignore\n");
	printf("   to jump over a word, or Add to add it to the local dictionary\n");
	printf("   in ~/.rospell/dictionary.user.\n");
	printf("\n");
	printf("   rospell supports UTF-8, ISO8859-2/16, and CP1250 character sets.\n");
	printf("   If the character set is not specified by --iso8859-2/16 or --cp1250,\n");
	printf("   UTF-8 is assumed.\n");
	printf("\n");
	printf("   rospell uses ALT key to enter Romanian special characters as follows:\n");
	printf("\n");
	printf("       ALT-a, ALT-s, ALT-q, ALT-t, ALT-i\n");
	printf("\n");
	printf("OPTIONS\n");
	printf("   -v: installed version\n");
	printf("\n");
	printf("   -h, -?, --help: this help screen.\n");
	printf("\n");
	printf("   --iso8859-2: use ISO8859-2 character set.\n");
	printf("\n");
	printf("   --iso8859-16: use ISO8859-16 character set.\n");
	printf("\n");
	printf("   --cp1250: use CP1250 (Windows) character set.\n");
	printf("\n");
	printf("   (the following options are only available for UTF-8 character set)\n");
	printf("\n");
	printf("   -m: add all words to Romanian master dictionary\n");
	printf("\n");
	printf("   -e: add all words to English master dictionary\n");
	printf("\n");
	printf("   -u: add all words to the local user dictionary\n");
	printf("\n");
	printf("   -p: print all new words\n");
	printf("\n");
	printf("EXAMPLE\n");
	printf("   $ rospell file*.txt\n");
	printf("   - start the editor using UTF-8 character set\n");
	printf("\n");
	printf("   $ rospell --iso8859-2 file*.txt\n");
	printf("   - start the editor using ISO8859-2 character set\n");
	printf("\n");
	printf("   $ rospell -p file*.txt\n");
	printf("   - generate a list of new words form file*.txt\n");
	printf("\n");
	printf("AUTHOR\n");
	printf("   http://rospell.sourceforge.net\n");
	printf("\n");
}

static Editor *start(const char *fname, FILE_FORMAT format) {
	LOG("start");
	Editor *e = new Editor;
	e->setDefaultFormat(format);
	if (fname == 0) {
		LOG("start with no file");
		e->setFname(0);
	} else {
		e->load(fname);
	}

	bool isSmall =  qApp->desktop()->size().width() < 450
				 || qApp->desktop()->size().height() < 450;

	if (isSmall) {
		e->showMaximized();
	} else {
		LOG("main: set editor sizes %d %d", Global::instance()->xsize, Global::instance()->ysize);
//		e->resize(Global::instance()->xsize, Global::instance()->ysize);
		e->show();
	}

	return e;
}

int main( int argc, char **argv )
{
	Action *aptr = 0;
	int start_arg = 1;
	LOG("argc %d", argc);
	LOG("argv %s %s", argv[0], argv[1]);

	FILE_FORMAT format = FILE_UTF8;

	if (argc > 1) {
		if (strcmp(argv[1], "--iso8859-2") == 0) {
			LOG("main: option -iso8859-2");
			format = FILE_ISO8859_2;
			start_arg = 2;
		}

		if (strcmp(argv[1], "--iso8859-16") == 0) {
			LOG("main: option -iso8859-16");
			format = FILE_ISO8859_16;
			start_arg = 2;
		}

		if (strcmp(argv[1], "--cp1250") == 0) {
			LOG("main: option -cp1250");
			format = FILE_CP1250;
			start_arg = 2;
		}

		if (strcmp(argv[1], "-m") == 0) { // Romanian master dict
			aptr = new ActionAddAllMaster();
			Global::instance()->addallmaster = true;
			LOG("Global::addallmaster = true");
			start_arg = 2;
			if (argc <= 2) {
				usage();
				return 1;
			}
		} else if (strcmp(argv[1], "-e") == 0) { // English master dict
			aptr = new ActionAddAllMasterEnglish();
			Global::instance()->addallmasterenglish = true;
			LOG("Global::addallmasterenglish = true");
			start_arg = 2;
			if (argc <= 2) {
				usage();
				return 1;
			}
		} else if (strcmp(argv[1], "-u") == 0) {
			aptr = new ActionAddAllUser();
			Global::instance()->addalluser = true;
			start_arg = 2;
			if (argc <= 2) {
				usage();
				return 1;
			}
		} else if (strcmp(argv[1], "-p") == 0) {
			aptr = new ActionDumpAll();
			Global::instance()->dumpall = true;
			start_arg = 2;
			if (argc <= 2) {
				usage();
				return 1;
			}
		} else if (strcmp(argv[1], "-h") == 0 ||
				 strcmp(argv[1], "-?") == 0 ||
				 strcmp(argv[1], "--help") == 0) {
			usage();
			return 0;
		} else if (strcmp(argv[1], "-v") == 0) {
			printf("rospell version %s\n", VERSION);
			return 0;
		}
	}

	if (aptr != 0) {
		// addallmaster (-m) and addallmasterenglish (-e) will not load the master dictionary
		// dumpall (-p) will load the master dictionary
		// addalluser (-u) will load the master dictionary
		bool readmaster = !(Global::instance()->addallmaster || Global::instance()->addallmasterenglish) ||
				   Global::instance()->dumpall ||
				   Global::instance()->addalluser;
		Dictionaries *pdict = new Dictionaries(readmaster);
	
		if (!Global::instance()->addallmaster && !Global::instance()->addallmasterenglish) {
			readHomeDir(pdict);
		}
	
		for (int i = start_arg; i < argc; i++) {
			char *fstr = UTILS::read_file_malloc(argv[i]);
			if (fstr == 0)
				continue;
			fprintf(stderr, "Process file %s\n", argv[i]);
			LOG("Process file %s", argv[i]);
			char *ptmp = spell(pdict, aptr, fstr);
			delete[] ptmp;
		}
		delete aptr;
	
		if (Global::instance()->addallmaster || Global::instance()->addallmasterenglish) {
			pdict->saveMaster();
		}
#ifndef _WIN32
		delete pdict;
#else
		LOG("problems with delete on windows (%s:%d)", __FILE__, __LINE__);
#endif
		Stats::instance()->print();
		Stats::instance(true);
		if (Global::instance()->addallmaster ||
		    Global::instance()->addallmasterenglish ||
		    Global::instance()->addalluser ||
		    Global::instance()->dumpall) {
			return 0;
		}
	}
	QApplication a( argc, argv);

	int i;
	Editor *e = 0;
	if (argc == start_arg) {
		e = start(0, format);
	}
	else {
		e = start(argv[start_arg], format);
		start_arg++;
		for (i= start_arg; i<argc; i++) {
			e->load(argv[i]);
		}
	}
	if (e == 0) // just in case!
		return 1;
	a.connect( &a, SIGNAL(lastWindowClosed()), &a, SLOT(quit()) );

	int retval = a.exec();
	delete e;
	Global::instance(true);
	Stats::instance(true);
	return retval;
//    return a.exec();
}
